--[[
Probably want to combine all information in one list to begin with.
Eventually add an option to filter by player.
]]

local backdropTable = {
	bgFile = [[Interface\DialogFrame\UI-DialogBox-Background]], --Interface\DialogFrame\UI-DialogBox-Header
	edgeFile = [[Interface\DialogFrame\UI-DialogBox-Border]],
	tile = true,
	tileSize = 32,    -- size (width or height) of the square repeating background tiles (in pixels)
	edgeSize = 32,    -- thickness of edge segments and square size of edge corners (in pixels)
	insets = {        -- distance from the edges of the frame to those of the background texture (in pixels)
		left = 11,
		right = 12,
		top = 12,
		bottom = 11
	}
}

---------------------------
--Set up the frame for the log of the specified player when called.
---------------------------
function TwitterRealID:SetupLog(...)
	--This will help reopen the message log later in the function if the log was open when they received an update.
	local action = ...

	--Create frame
	--Get existing data for player and run compare
	local logFrame = LogFrame or CreateFrame("Frame","LogFrame",UIParent)
	logFrame:SetSize(720, 640)
	logFrame:SetBackdrop(backdropTable)
	logFrame:SetPoint("CENTER",0,0)

	--Create the texture for the title
	local title = logFrame:CreateTexture()
	title:SetTexture([[Interface\DialogFrame\UI-DialogBox-Header]])
	title:SetWidth(256)
	title:SetHeight(64)
	title:SetPoint("TOP", logFrame, 0, 12)

	local titleString = logFrame:CreateFontString(nil, "ARTWORK", "GameFontNormal")
	titleString:SetText("TRID Log")
	titleString:SetPoint("TOP", logFrame, 0, -2)

	--Create the ScrollFrame to display the log
	local sfHeight = 570
	local sfWidth = 656
	local logSF = LogScrollFrame or CreateFrame("ScrollFrame", "LogScrollFrame", logFrame)
	logSF:SetSize(sfWidth, sfHeight)
	logSF:SetPoint("CENTER", 0, -16)

	--Create the scroll frame's child frame
	local logSFChild = LogScrollFrameChild or CreateFrame("Frame", "LogScrollFrameChild")
	logSFChild:SetSize(50, 16)
	logSFChild:SetPoint("CENTER", 0, 0)

	logSF:SetScrollChild(logSFChild)

	--Create the slider for the scroll frame
	local logSFSlider = LSFSlider or CreateFrame("Slider", "LSFSlider", logSF)

	--Set up background for slider
	logSFSlider.bg = logSFSlider:CreateTexture(nil, "BACKGROUND")
	logSFSlider.bg:SetAllPoints(true)
	logSFSlider.bg:SetTexture(0, 0, 0, 0.25)

	--Set up the thumb on the slider
	logSFSlider.thumb = logSFSlider:CreateTexture(nil, "OVERLAY")
	logSFSlider.thumb:SetTexture([[Interface\Buttons\UI-ScrollBar-Knob]])
	logSFSlider.thumb:SetSize(25, 25)
	logSFSlider:SetThumbTexture(logSFSlider.thumb)


	--Some values to help populate the data
	local entryY = 16
	local yIncrement = 16
	local x1, x2 = 0, 215
	logSFChild.logEntryDate = logSFChild.logEntryDate or {}
	logSFChild.logEntryMessage = logSFChild.logEntryMessage or {}

	--Set up titles for the two columns
	local dateTitle = logSF:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	dateTitle:SetText("Date")
	dateTitle:SetPoint("TOPLEFT", logSF, "TOPLEFT", x1, 24)
	local messageTitle = logSF:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	messageTitle:SetText("Message")
	messageTitle:SetPoint("TOPLEFT", logSF, "TOPLEFT", x2, 24)

	--Populate the data in two columns
	for i, v in ipairs (TRID_DB.log) do
		for i1, v1 in pairs (v) do
			--set date
			logSFChild.logEntryDate[i] = logSFChild.logEntryDate[i] or logSFChild:CreateFontString(nil, "ARTWORK", "GameFontNormal")
			local timeString = TwitterRealID:GetTimeString(i1)
			logSFChild.logEntryDate[i]:SetText(timeString)
			logSFChild.logEntryDate[i]:SetPoint("TOPLEFT", logSFChild, "BOTTOMLEFT", x1, entryY)

			--set message
			logSFChild.logEntryMessage[i] = logSFChild.logEntryMessage[i] or logSFChild:CreateFontString(nil, "ARTWORK", "GameFontNormal")
			logSFChild.logEntryMessage[i]:SetText(v1)
			logSFChild.logEntryMessage[i]:SetPoint("TOPLEFT", logSFChild, "BOTTOMLEFT", x2, entryY)

			entryY = entryY - yIncrement
		end
	end

	--Get the scroll bar working
	local sHeight = -entryY - sfHeight + yIncrement
	if sHeight < 0 then
		sHeight = 0
	end
	logSFSlider:SetOrientation("VERTICAL")
	logSFSlider:SetSize(16, sfHeight) --Want this slider to be the same height as the scroll frame
	logSFSlider:SetPoint("TOPLEFT", logSF, "TOPRIGHT", 0, 0)
	logSFSlider:SetMinMaxValues(0, sHeight) --This sets the scroll range of the slider/scroll frame
	logSFSlider:SetValue(0)
	logSFSlider:SetScript("OnValueChanged", function(self)
		logSF:SetVerticalScroll(self:GetValue())
	end)

	--Scrolling functionality
	logSF:EnableMouseWheel(true)
	logSF:SetScript("OnMouseWheel", function(self, delta)
		local current = logSFSlider:GetValue()

		if IsShiftKeyDown() and (delta > 0) then
			logSFSlider:SetValue(0)
		elseif IsShiftKeyDown() and (delta < 0) then
			logSFSlider:SetValue(sHeight)
		elseif (delta < 0) and (current < sHeight) then
			logSFSlider:SetValue(current + 20)
		elseif (delta > 0) and (current > 1) then
			logSFSlider:SetValue(current - 20)
		end
	end)

	--If the frame is open and visible, refresh it. Otherwise, leave it hidden
	if action == "UPDATE" and logFrame:IsVisible() then
		logFrame:Show()
	else
		logFrame:Hide()
	end

	return logFrame
end

---------------------------
--Create nicely readable date/time strings from a date passed in YYYYMMDD
---------------------------
function TwitterRealID:GetTimeString(eventTime)
	local monthTable = {
		"January",
		"February",
		"March",
		"April",
		"May",
		"June",
		"July",
		"August",
		"September",
		"October",
		"November",
		"December"
	}

	local month = monthTable[tonumber(string.sub(eventTime, 5, 6))]
	local day = string.sub(eventTime, 7, 8)
	local year= string.sub(eventTime, 1, 4)
	local totalMins = string.sub(eventTime, 9, 12)
	local daytime = "AM"

	--work out hours
	local hours = math.floor(totalMins/60)

	--figure out if am/pm
	if hours > 12 then
		hours = hours - 12
		daytime = "PM"
	end

	--make sure 0 is reported correctly as 12
	if hours == 0 then
		hours = 12
	end

	--work out mins
	local mins = totalMins%60
	while string.len(mins) < 2 do
		mins = "0"..mins
	end


	local convertedString = month.." "..day..", "..year.." "..hours..":"..mins.." "..daytime

	return convertedString
end

---------------------------
--Takes new log and compares it to existing records.
---------------------------
function TwitterRealID:CompareLog()

end

---------------------------
--Sets up the drop down menu
---------------------------
function TwitterRealID:SetupDropDown()
	--UIDropDownMenu_Initialize(frame, initFunction, displayMode, level, menuList)
end

---------------------------
--Figures out the realm time of the active character
---------------------------
function TwitterRealID:GetRealmTime()
	--This retrieves the region they are in US/EU
	--string.sub(GetCVar("realmList"), 1, 2)
	local hours, minutes = GetGameTime()
	local weekday, month, day, year = CalendarGetDate()

	local totalMins = hours * 60 + minutes

	--Pad the minutes to four digits
	while string.len(totalMins) < 4 do
		totalMins = "0"..totalMins
	end

	--Pad day to two digits
	while string.len(day) < 2 do
		day = "0"..day
	end

	--Pad month to two digits
	while string.len(month) < 2 do
		month = "0"..month
	end

	local realmTime = year..month..day..totalMins
	return realmTime
end
